[Cmake-commits] CMake branch, next, updated. v3.1.1-2547-g70fd484

Brad King brad.king at kitware.com
Tue Feb 3 10:01:34 EST 2015


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
       via  70fd484a81d55b9177b48f460f4d37d12089d0b2 (commit)
       via  d7b3f1d19326bb0221562d6b4e1006eb40251650 (commit)
      from  98e6914a157b219ef6b5b70c3ba699a3402e633f (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=70fd484a81d55b9177b48f460f4d37d12089d0b2
commit 70fd484a81d55b9177b48f460f4d37d12089d0b2
Merge: 98e6914 d7b3f1d
Author:     Brad King <brad.king at kitware.com>
AuthorDate: Tue Feb 3 10:01:34 2015 -0500
Commit:     CMake Topic Stage <kwrobot at kitware.com>
CommitDate: Tue Feb 3 10:01:34 2015 -0500

    Merge topic 'CTestCoverageCollectGCOV-refinements' into next
    
    d7b3f1d1 CTestCoverageCollectGCOV: Rename GCOV_{EXTRA_ => }OPTIONS


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=d7b3f1d19326bb0221562d6b4e1006eb40251650
commit d7b3f1d19326bb0221562d6b4e1006eb40251650
Author:     Brad King <brad.king at kitware.com>
AuthorDate: Tue Feb 3 09:58:36 2015 -0500
Commit:     Brad King <brad.king at kitware.com>
CommitDate: Tue Feb 3 09:58:36 2015 -0500

    CTestCoverageCollectGCOV: Rename GCOV_{EXTRA_ => }OPTIONS

diff --git a/Tests/CTestCoverageCollectGCOV/test.cmake.in b/Tests/CTestCoverageCollectGCOV/test.cmake.in
index 2560542..4bdcb10 100644
--- a/Tests/CTestCoverageCollectGCOV/test.cmake.in
+++ b/Tests/CTestCoverageCollectGCOV/test.cmake.in
@@ -19,7 +19,7 @@ ctest_coverage_collect_gcov(
   SOURCE "${CTEST_SOURCE_DIRECTORY}"
   BUILD "${CTEST_BINARY_DIRECTORY}"
   GCOV_COMMAND "${CMAKE_COMMAND}"
-  GCOV_EXTRA_OPTIONS -P "@CMake_SOURCE_DIR@/Tests/CTestCoverageCollectGCOV/fakegcov.cmake")
+  GCOV_OPTIONS -P "@CMake_SOURCE_DIR@/Tests/CTestCoverageCollectGCOV/fakegcov.cmake")
 
 execute_process(COMMAND
       ${CMAKE_COMMAND} -E tar tf ${tar_file}

-----------------------------------------------------------------------

Summary of changes:
 Modules/CTestCoverageCollectGCOV.cmake       |   20 +++++++++-----------
 Tests/CTestCoverageCollectGCOV/test.cmake.in |    2 +-
 2 files changed, 10 insertions(+), 12 deletions(-)


hooks/post-receive
diff --git a/Modules/CTestCoverageCollectGCOV.cmake b/Modules/CTestCoverageCollectGCOV.cmake
index 037d3bc..dd10e83 100644
--- a/Modules/CTestCoverageCollectGCOV.cmake
+++ b/Modules/CTestCoverageCollectGCOV.cmake
@@ -19,7 +19,7 @@
 #     ctest_coverage_collect_gcov(TARBALL <tarfile>
 #       [SOURCE <source_dir>][BUILD <build_dir>]
 #       [GCOV_COMMAND <gcov_command>]
-#       [GCOV_EXTRA_OPTIONS <extra_options>...]
+#       [GCOV_OPTIONS <options>...]
 #       )
 #
 #   Run gcov and package a tar file for CDash.  The options are:
@@ -41,12 +41,10 @@
 #     Specify the full path to the ``gcov`` command on the machine.
 #     Default is the value of :variable:`CTEST_COVERAGE_COMMAND`.
 #
-#   ``GCOV_EXTRA_OPTIONS <extra_options>...``
-#     Specify extra options to be passed to gcov.  By default
-#     gcov is run as ``gcov -b -o <gcov-dir> <file>.gcda``.
-#     If GCOV_EXTRA_OPTIONS is specified, gcov will be run as
-#     ``gcov <extra_options>... -o <gcov-dir> <file>.gcda``.
-
+#   ``GCOV_OPTIONS <options>...``
+#     Specify options to be passed to gcov.  The ``gcov`` command
+#     is run as ``gcov <options>... -o <gcov-dir> <file>.gcda``.
+#     If not specified, the default option is just ``-b``.
 
 #=============================================================================
 # Copyright 2014-2015 Kitware, Inc.
@@ -64,7 +62,7 @@ include(CMakeParseArguments)
 function(ctest_coverage_collect_gcov)
   set(options "")
   set(oneValueArgs TARBALL SOURCE BUILD GCOV_COMMAND)
-  set(multiValueArgs GCOV_EXTRA_OPTIONS)
+  set(multiValueArgs GCOV_OPTIONS)
   cmake_parse_arguments(GCOV  "${options}" "${oneValueArgs}"
     "${multiValueArgs}" "" ${ARGN} )
   if(NOT DEFINED GCOV_TARBALL)
@@ -121,11 +119,11 @@ function(ctest_coverage_collect_gcov)
     get_filename_component(gcov_dir ${gcda_file} DIRECTORY)
     # run gcov, this will produce the .gcov file in the current
     # working directory
-    if(NOT DEFINED GCOV_GCOV_EXTRA_OPTIONS)
-      set(GCOV_GCOV_EXTRA_OPTIONS -b)
+    if(NOT DEFINED GCOV_GCOV_OPTIONS)
+      set(GCOV_GCOV_OPTIONS -b)
     endif()
     execute_process(COMMAND
-      ${gcov_command} ${GCOV_GCOV_EXTRA_OPTIONS} -o ${gcov_dir} ${gcda_file}
+      ${gcov_command} ${GCOV_GCOV_OPTIONS} -o ${gcov_dir} ${gcda_file}
       OUTPUT_VARIABLE out
       RESULT_VARIABLE res
       WORKING_DIRECTORY ${coverage_dir})
-- 
CMake


More information about the Cmake-commits mailing list